.. highlight:: shell

============
Installation
============


Stable release
--------------

To install deepbiome, run this command in your terminal:

.. code-block:: console

    # for python 3.x
    
    $ pip install deepbiome

This is the preferred method to install deepbiome, as it will always install the most recent stable release.

If you want to install the latest version:

.. code-block:: console

    # for python 3.x
    
    $ pip install git+https://github.com/Young-won/deepbiome.git

If you don't have `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/


From sources
------------

The sources for deepmicrobiome can be downloaded from the `Github repo`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/Young-won/deepbiome

Once you have a copy of the source, you can install it with:

.. code-block:: console

    # for python 3.x

    $ python setup.py install

.. _Github repo: https://github.com/Young-won/deepbiome
